ispx

package module
v0.0.0-...-6071d09 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2026 License: Apache-2.0 Imports: 114 Imported by: 0

README

ispx

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(files map[string][]byte) error

Build builds the spx code from the provided files into the interpreter.

func BuildFS

func BuildFS(fsys fs.FS) error

BuildFS builds the spx code from the provided file system into the interpreter.

func Init

func Init(ctx *ixgo.Context) error

Init initializes the interpreter with the given ctx, which must not be modified after used. It can only be called once.

If ctx is nil, a default ixgo.Context will be created.

If ctx.Lookup is nil, a default lookup function will be set.

func Run

func Run() (exitCode int, err error)

Run runs the interpreter. It blocks until the interpreter exits. After it returns, the interpreter must be rebuilt before running again.

func UnsafeRelease

func UnsafeRelease()

UnsafeRelease releases the interpreter's resources. It is unsafe to call while the interpreter is running.

Types

This section is empty.

Directories

Path Synopsis
cmd
ispx command
ispxpc command
internal

Jump to