ispx

package
v2.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2026 License: Apache-2.0 Imports: 117 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(files map[string][]byte) error

Build builds the spx code from the provided files into the interpreter.

func BuildFS

func BuildFS(fsys fs.FS) error

BuildFS builds the spx code from the provided file system into the interpreter.

func Init

func Init(ctx *ixgo.Context) error

Init initializes the interpreter with the given ctx, which must not be modified after used. It can only be called once.

If ctx is nil, a default ixgo.Context will be created.

If ctx.Lookup is nil, a default lookup function will be set.

func Run

func Run() (exitCode int, err error)

Run runs the interpreter. It blocks until the interpreter exits. After it returns, the interpreter must be rebuilt before running again.

func Shutdown

func Shutdown() error

Shutdown requests the game to stop and waits for it to exit.

Types

This section is empty.

Jump to