Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Init ¶
Init initializes the interpreter with the given ctx, which must not be modified after used. It can only be called once.
If ctx is nil, a default ixgo.Context will be created.
If ctx.Lookup is nil, a default lookup function will be set.
func Run ¶
Run runs the interpreter. It blocks until the interpreter exits. After it returns, the interpreter must be rebuilt before running again.
func UnsafeRelease ¶
func UnsafeRelease()
UnsafeRelease releases the interpreter's resources. It is unsafe to call while the interpreter is running.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.